@@ -20,8 +20,7 @@
 import sys, os, tempfile, shutil
 from os.path import join, dirname, abspath
 import datetime, time
-
-from six.moves import range
+from unittest.mock import patch
 
 from logilab.common.testlib import TestCase, unittest_main
 
@@ -180,6 +179,12 @@ class RawInputTC(TestCase):
         null_printer = lambda x: None
         self.qa = RawInput(self.auto_input, null_printer)
 
+    def test_ask_using_builtin_input(self):
+        with patch('builtins.input', return_value='no'):
+            qa = RawInput()
+            answer = qa.ask('text', ('yes', 'no'), 'yes')
+        self.assertEqual(answer, 'no')
+
     def test_ask_default(self):
         self.input_answer = ''
         answer = self.qa.ask('text', ('yes', 'no'), 'yes')
